@@ -10,7 +10,8 @@ from .__common__ import *
 from .__info__ import __author__, __copyright__, __email__, __license__, __source__, __version__
 
 
-__all__ = ["add", "add_map", "clear", "decode", "encode", "guess", "lookup",  "open", "register", "remove", "reset"]
+__all__ = ["add", "add_map", "clear", "decode", "encode", "guess", "lookup",  "open", "rank", "register", "remove",
+           "reset"]
 
 decode   = codecs.decode
 encode   = codecs.encode
