@@ -9,18 +9,26 @@ This codec:
 - decodes file content to str (read)
 - encodes file content from str to bytes (write)
 """
+from ._base import main
 from ..__common__ import *
 
 
 # no __examples__ ; handled manually in tests/test_base.py
 
 
+def base100_encode(input, errors='strict'):
+    raise NotImplementedError
+
+
+def base100_decode(input, errors='strict'):
+    raise NotImplementedError
+
+
 if PY3:
     class Base100DecodeError(ValueError):
         pass
     
-    
-    def base100_encode(input, errors='strict'):
+    def base100_encode(input, errors="strict"):
         input = b(input)
         r = [240, 159, 0, 0] * len(input)
         for i, c in enumerate(input):
@@ -28,9 +36,10 @@ if PY3:
             r[4*i+3] = (c + 55) % 64 + 128
         return bytes(r), len(input)
     
-    
-    def base100_decode(input, errors='strict'):
+    def base100_decode(input, errors="strict"):
         input = b(input)
+        if errors == "ignore":
+            input = input.replace(b"\n", "")
         if len(input) % 4 != 0:
             raise Base100DecodeError("Bad input (length should be multiple of 4)")
         r = [None] * (len(input) // 4)
@@ -42,5 +51,6 @@ if PY3:
         return bytes(r), len(input)
     
     
-    add("base100", base100_encode, base100_decode, r"^(?:base[-_]?100|emoji)$")
+add("base100", base100_encode, base100_decode, r"^(?:base[-_]?100|emoji)$")
+main = main(100, "<https://github.com/AdamNiederer/base100>")
 
