@@ -3,11 +3,13 @@
 """Base codecs tests.
 
 """
+import os
+import sys
 from unittest import TestCase
 
 from codext.__common__ import *
 from codext.base._base import _generate_charset
-from codext.base.baseN import base
+from codext.base.baseN import base, main2, main32, main64url
 
 
 class TestCodecsBase(TestCase):
@@ -209,6 +211,17 @@ class TestCodecsBase(TestCase):
         self.assertIsNotNone(codecs.decode("AD", "base91"))
         self.assertRaises(ValueError, codecs.decode, "\xff", "base91")
         self.assertRaises(ValueError, codecs.decode, "a\xff", "base91")
+        B91A = "Jx&[jv4S3Wg>,71@Jk"
+        self.assertEqual(codecs.encode(STR, "base91-alt"), B91A)
+        self.assertEqual(codecs.encode(b(STR), "base91-alt"), b(B91A))
+        self.assertEqual(codecs.decode(B91A, "base91_alt"), STR)
+        self.assertEqual(codecs.decode(b(B91A), "base91_alt"), b(STR))
+        B91A = "jX&[JV4s3wG>,71@jK"
+        self.assertEqual(codecs.encode(STR, "base91-alt-inv"), B91A)
+        self.assertEqual(codecs.decode(B91A, "base91_alt_inv"), STR)
+        self.assertIsNotNone(codecs.encode("\x00\x00", "base91-alt"))
+        self.assertIsNotNone(codecs.decode("abc", "base91-alt"))
+        self.assertIsNotNone(codecs.decode("AD", "base91_alt"))
     
     def test_codec_base100(self):
         if PY3:
@@ -227,4 +240,17 @@ class TestCodecsBase(TestCase):
         self.assertRaises(LookupError, codecs.decode, "test", "base0-generic")
         self.assertRaises(LookupError, codecs.decode, "test", "base1-generic")
         self.assertRaises(LookupError, codecs.decode, "test", "base256-generic")
+    
+    def test_base_main(self):
+        tmp = sys.argv[:]
+        tfile = "test-base-main.txt"
+        with open(tfile, 'w') as f:
+            f.write("This is a long test string for the sake of causing line wrapping based on default parameters.")
+        sys.argv = [tmp[0], tfile]
+        for m in main32, main64url:
+            self.assertEqual(m(), 0)
+        sys.argv = [tmp[0], tfile, "-d"]
+        self.assertEqual(main2(), 1)
+        os.remove(tfile)
+        sys.argv[:] = tmp
 
